# Changelog

## [0.4.1](https://github.com/bdesanctis/bamdam/compare/v0.4.0...v0.4.1) (2025-11-18)


### Dependencies

* update pysam ([71e5923](https://github.com/bdesanctis/bamdam/commit/71e5923a47a6d26e1c95acefd027e0fbd510693c))

## [0.4.0](https://github.com/bdesanctis/bamdam/compare/v0.3.0...v0.4.0) (2025-11-18)


### Dependencies

* remove pysam from both dev and main deps ([ebaf991](https://github.com/bdesanctis/bamdam/commit/ebaf991962b95507a9bf4aefbab54ff56e8eb2b9))


### Miscellaneous Chores

* release 0.4.0 ([5f9ec9e](https://github.com/bdesanctis/bamdam/commit/5f9ec9ed073923ad9f7c9c7067c49f09c6d1b9a0))

## [0.3.0](https://github.com/bdesanctis/bamdam/compare/v0.2.2...v0.3.0) (2025-09-25)


### Features

* many small additions and fixes ([37a99d4](https://github.com/bdesanctis/bamdam/commit/37a99d4e942bd1e9fbd20f10b244fe92b28a183e))


### Bug Fixes

* correct shrink test arguments ([0d37984](https://github.com/bdesanctis/bamdam/commit/0d37984ca7f4670bbd1db7509eccbec79e7b5a8f))
* modularization bug fix ([ea8e551](https://github.com/bdesanctis/bamdam/commit/ea8e5516bcbb9326c23381001c3e68cd07f5a9e9))
* shrink test attributes ([0d6f40a](https://github.com/bdesanctis/bamdam/commit/0d6f40afd352ee7a7a128196c9e89d610257a652))
* small bug in combine input arguments ([7e972fc](https://github.com/bdesanctis/bamdam/commit/7e972fc0e72cf3d2c30ed891cd0485783ecf71a1))

## [0.2.2](https://github.com/bdesanctis/bamdam/compare/v0.2.1...v0.2.2) (2025-07-09)


### Bug Fixes

* modularization bug fix ([ea8e551](https://github.com/bdesanctis/bamdam/commit/ea8e5516bcbb9326c23381001c3e68cd07f5a9e9))

## [0.2.1](https://github.com/bdesanctis/bamdam/compare/v0.2.0...v0.2.1) (2025-07-03)


### Bug Fixes

* update imports and tests ([2d4ed29](https://github.com/bdesanctis/bamdam/commit/2d4ed299247211bbda4f90cc77e4173358a594c6))


### Documentation

* update changelog ([3706cd1](https://github.com/bdesanctis/bamdam/commit/3706cd170ea6a6d1a78cb7478e493a4f29de3c47))

## [0.2.0](https://github.com/bdesanctis/bamdam/compare/v0.1.2...v0.2.0) (2025-06-11)


### Features

* add threading option for shrink ([15e05c6](https://github.com/bdesanctis/bamdam/commit/15e05c6))
* optimize compute by using lru cache and reduce string ops ([e0c3a08](https://github.com/bdesanctis/bamdam/commit/e0c3a08))


### Bug Fixes

* update tests ([353546e](https://github.com/bdesanctis/bamdam/commit/353546e))


### Miscellaneous Chores

* release 0.2.0 ([1b20f30](https://github.com/bdesanctis/bamdam/commit/1b20f30f0d7c29bd4ba085851d96cbd9b7110897))

## [0.1.2](https://github.com/bdesanctis/bamdam/compare/v0.1.1...v0.1.2) (2025-06-03)


### Bug Fixes

* added GC content and more averaging to the combine function, fixed ^Ms at ends of tsv file lines, added an empty lca error catch ([00c492c](https://github.com/bdesanctis/bamdam/commit/00c492c844d3aa78e5f7552ab28334b03c9adc9d))


### Documentation

* update install, add workflow img ([f231807](https://github.com/bdesanctis/bamdam/commit/f231807ffedd807d1e4e619a21ef6843b14c3d93))

## [0.1.1](https://github.com/bdesanctis/bamdam/compare/v0.1.0...v0.1.1) (2025-04-07)


### Bug Fixes

* rename release workflow file ([f7790e5](https://github.com/bdesanctis/bamdam/commit/f7790e565bba3940f6fc3d6834685bf4b87a3273))

## 0.1.0 (2025-04-07)


### Miscellaneous Chores

* release 0.1.0 ([f21226a](https://github.com/bdesanctis/bamdam/commit/f21226a36e5aa53ac349a701994ab2002f64abd8))
